@@ -69,12 +69,12 @@ def trailerDownload(taskQueue, taskDict):
                        targetDir,
                        '--progress=dot:mega']
             downloadFunc(trailerURL, command, taskDict)
-    except ClosingException, e:
+    except ClosingException as e:
         pass
 
 wgetPids=[]
 def downloadFunc(trailerURL, command, taskDict):
-    print "Executing: %s" % " ".join(command)
+    print("Executing: %s" % " ".join(command))
     p = subprocess.Popen(command,
                          stdout=subprocess.PIPE,
                          stderr=subprocess.PIPE)
@@ -83,7 +83,7 @@ def downloadFunc(trailerURL, command, taskDict):
     wgetPids.append(p.pid)
     totalsize = 0
     while True:
-        line = p.stderr.readline()
+        line = p.stderr.readline().decode()
         if len(line) == 0:
             break
         if line.find('Length:') != -1:
@@ -93,20 +93,20 @@ def downloadFunc(trailerURL, command, taskDict):
     # now we start counting dots :-)
     downloaded = 0
     while True:
-        x = p.stderr.read(1)
+        x = p.stderr.read(1).decode()
 
         if len(x) == 0:
             break
         if x == '.' or x ==',':
             downloaded = downloaded + 64 * 1024
-        perc = downloaded * 100 / totalsize
+        perc = int(downloaded * 100 / totalsize)
         if perc % 5 == 0:
             try:
                 taskDict[trailerURL] = DownloadStatus(trailerURL,
                            DownloadStatus.IN_PROGRESS,
                            perc)
             except IOError as e:
-                print "Ignoring interrupted assignement exception"
+                print("Ignoring interrupted assignement exception")
                 if e.errno is not errno.EINTR:
                     raise
 
@@ -122,6 +122,6 @@ def downloadFunc(trailerURL, command, taskDict):
 
 def term_handler(signum, frame):
     for p in wgetPids:
-        print 'Stopping wget process ', p
+        print('Stopping wget process ', p)
         os.kill(p, signal.SIGTERM)
     raise ClosingException("Finishing up")
