@@ -1,12 +1,18 @@
-import pickle
-import time
+import json
 import locale
 import re
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
-from about_ui import Ui_AboutDialog
-from settings_ui import Ui_SettingsDialog
+
+try:
+    from PyQt4.QtCore import QString
+except ImportError:
+    # we are using Python3 so QString is not defined
+    QString = type("")
+
+from .settings_ui import Ui_SettingsDialog
+from .about_ui import Ui_AboutDialog
 from .. import version
 __version__ = version.__version__
 import dateutil.parser as dparser
@@ -19,12 +25,14 @@ class MovieItemWidget(QFrame):
         self.filters = trailerFilters
 
         self.titlebox = QHBoxLayout()
-        locale.setlocale(locale.LC_ALL, "C")
         releaseDate=None
-        if movie.releasedate:
+        if hasattr(movie, "releasedate"):
+            locale.setlocale(locale.LC_ALL, "C")
             releaseDate = dparser.parse(movie.releasedate)
             locale.resetlocale()
             releaseDate = releaseDate.strftime("%x")
+        else:
+            releaseDate = "Unknown release date"
         titleLabel = QLabel("<h2>%s</h2> (Release date: %s)" %
         (movie.title, releaseDate), self)
         self.setFrameStyle(QFrame.Panel | QFrame.Sunken);
@@ -39,17 +47,20 @@ class MovieItemWidget(QFrame):
 
         mainArea = QVBoxLayout()
         self.mainArea = mainArea
-        if movie.genre:
-            genStr = ", ".join(movie.genre)
-        else:
-            genStr = "Unknown"
-        genre = QLabel("<b>Genre(s): </b>%s" % genStr)
+        genre = QLabel("<b>Genre(s): </b>%s" %
+                       self.__get_movie_info(movie, "genre", True))
         mainArea.addWidget(genre)
-        studio = QLabel("<b>Studio: </b>%s" % movie.studio)
+
+        studio = QLabel("<b>Studio: </b>%s" %
+                        self.__get_movie_info(movie, "studio"))
         mainArea.addWidget(studio)
-        directors = QLabel("<b>Director(s): </b>%s" % movie.directors)
+
+        directors = QLabel("<b>Director(s): </b>%s" %
+                           self.__get_movie_info(movie, "directors"))
         mainArea.addWidget(directors)
-        actors = QLabel("<b>Actors: </b>%s" % ", ".join(movie.actors))
+
+        actors = QLabel("<b>Actors: </b>%s" %
+                        self.__get_movie_info(movie, "actors", True))
         mainArea.addWidget(actors)
         actors.setWordWrap(True)
         mainArea.addStretch(1)
@@ -64,6 +75,15 @@ class MovieItemWidget(QFrame):
         self.setMinimumSize(400,150)
         self.setLayout(topLevelLayout)
 
+    def __get_movie_info(self, movie, info, join=False):
+        ret = "Unknown"
+        if hasattr(movie, info):
+            if join:
+                ret = ", ".join(getattr(movie, info))
+            else:
+                ret = getattr(movie, info)
+        return ret
+
     def refresh(self):
 
         movie = self.movie
@@ -123,7 +143,7 @@ class MovieItemWidget(QFrame):
 
     def view(self, button):
         id = self.viewButtons.id(button)
-        self.viewClicked.emit(self.movie.trailerLinks[id])
+        self.viewClicked.emit(self.button_mapping[id])
 
 
 class PyTrailerSettings(QDialog):
@@ -147,7 +167,9 @@ class PyTrailerSettings(QDialog):
         self.ui.qualityUp.clicked.connect(self.filterUp)
         self.ui.qualityDown.clicked.connect(self.filterDown)
 
-        activeFilters = pickle.loads(config.get("DEFAULT","filters"))
+        self.ui.playerCommand.setText(config.get("DEFAULT","player"))
+
+        activeFilters = json.loads(config.get("DEFAULT","filters"))
         self.ui.filterList.clear()
         added = []
         for filt in activeFilters:
@@ -182,6 +204,8 @@ class PyTrailerSettings(QDialog):
     def accept(self):
         self.config.set("DEFAULT","downloadDir",
                         str(self.ui.downloadPath.text()))
+        playerStr = self.ui.playerCommand.text().replace('%','%%')
+        self.config.set("DEFAULT","player", playerStr)
         activeFilters = []
         for i in range(self.ui.filterList.count()):
             itemWidget = self.ui.filterList.takeItem(0)
@@ -189,7 +213,7 @@ class PyTrailerSettings(QDialog):
             for fn, fregex in self.filters:
                 if fn == filterName:
                     activeFilters.append(fregex)
-        self.config.set("DEFAULT","filters", pickle.dumps(activeFilters))
+        self.config.set("DEFAULT","filters", json.dumps(activeFilters))
         self.config.set("DEFAULT","readAhead", str(self.ui.spinReadAhead.value()))
         self.config.set("DEFAULT","parallelDownload", str(self.ui.spinParallelDownload.value()))
         QDialog.accept(self)
